==> IOSCSIArchitectureModelFamily-130.3.8.tar.gz: IOSCSIArchitectureModelFamily-130.3.8/TestTools/STUC/UnitTests/Authoring/Cocoa/MyDocument.h <==
/*
 *  Copyright 2001-2003 Apple Computer, Inc. All rights reserved.
 *
 * IMPORTANT:  This Apple software is supplied to you by Apple Computer, Inc. (Apple) in 
 * consideration of your agreement to the following terms, and your use, installation, 
 * modification or redistribution of this Apple software constitutes acceptance of these
 * terms.  If you do not agree with these terms, please do not use, install, modify or 
 * redistribute this Apple software.
 *
 * In consideration of your agreement to abide by the following terms, and subject to these 
 * terms, Apple grants you a personal, non exclusive license, under Apples copyrights in this 
 * original Apple software (the Apple Software), to use, reproduce, modify and redistribute 
 * the Apple Software, with or without modifications, in source and/or binary forms; provided 
 * that if you redistribute the Apple Software in its entirety and without modifications, you 
 * must retain this notice and the following text and disclaimers in all such redistributions 
 * of the Apple Software.  Neither the name, trademarks, service marks or logos of Apple 
 * Computer, Inc. may be used to endorse or promote products derived from the Apple Software 
 * without specific prior written permission from Apple. Except as expressly stated in this 
 * notice, no other rights or licenses, express or implied, are granted by Apple herein, 
 * including but not limited to any patent rights that may be infringed by your derivative 
 * works or by other works in which the Apple Software may be incorporated.
 * 
 * The Apple Software is provided by Apple on an "AS IS" basis.  APPLE MAKES NO WARRANTIES, 
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-
 * INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE 
 * SOFTWARE OR ITS USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 *
 * IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, 
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE, HOWEVER CAUSED AND 
 * WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR 
 * OTHERWISE, EVEN IF APPLE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


//
//	Includes
//

#import <Cocoa/Cocoa.h>
#import <IOKit/scsi/SCSITaskLib.h>
#import "AuthoringDeviceTester.h"


//
// NB: This code example requires Jaguar or later in order to work.
//

@interface MyDocument : NSDocument
{
	
	IBOutlet NSTextView *		testOutputTextView;
	IBOutlet NSButton *			testButton;
	IBOutlet NSPopUpButton *	testPopUpButton;
	IBOutlet NSButton *			exclusiveAccessButton;
	IBOutlet NSButton *			isExclusiveAccessAvailableButton;
	IBOutlet NSWindow *			theWindow;
	id							theAuthoringDeviceTester;
	id							theAuthoringDevice;
	
}

+ ( MyDocument * ) myDocument;

- ( NSWindow * ) theWindow;

- ( id ) theAuthoringDeviceTester;
- ( void ) setTheAuthoringDeviceTester: ( id ) value;

- ( id ) theAuthoringDevice;
- ( void ) setTheAuthoringDevice: ( id ) value;

- ( void ) runExclusiveTestSuite: ( SCSITaskDeviceInterface ** ) interface;
- ( int ) unmountMedia;
- ( int ) findWholeMediaBSDName: ( io_service_t ) ioMediaNub;
- ( int ) unmountAllPartitions: ( CFStringRef ) bsdName;

- ( IBAction ) switchTest: ( id ) sender;
- ( IBAction ) getExclusiveAccess: ( id ) sender;
- ( IBAction ) isExclusiveAccessAvailable: ( id ) sender;


//
//				Helper Methods
//

- ( void ) appendLogText: ( NSString * ) logString;
- ( IBAction ) clearLog: ( id ) sender;


@end

==> IOSCSIArchitectureModelFamily-137.3.5.tar.gz: IOSCSIArchitectureModelFamily-137.3.5/TestTools/STUC/UnitTests/Authoring/Cocoa/MyDocument.h <==
/*
 *  Copyright 2001-2003 Apple Computer, Inc. All rights reserved.
 *
 * IMPORTANT:  This Apple software is supplied to you by Apple Computer, Inc. (Apple) in 
 * consideration of your agreement to the following terms, and your use, installation, 
 * modification or redistribution of this Apple software constitutes acceptance of these
 * terms.  If you do not agree with these terms, please do not use, install, modify or 
 * redistribute this Apple software.
 *
 * In consideration of your agreement to abide by the following terms, and subject to these 
 * terms, Apple grants you a personal, non exclusive license, under Apples copyrights in this 
 * original Apple software (the Apple Software), to use, reproduce, modify and redistribute 
 * the Apple Software, with or without modifications, in source and/or binary forms; provided 
 * that if you redistribute the Apple Software in its entirety and without modifications, you 
 * must retain this notice and the following text and disclaimers in all such redistributions 
 * of the Apple Software.  Neither the name, trademarks, service marks or logos of Apple 
 * Computer, Inc. may be used to endorse or promote products derived from the Apple Software 
 * without specific prior written permission from Apple. Except as expressly stated in this 
 * notice, no other rights or licenses, express or implied, are granted by Apple herein, 
 * including but not limited to any patent rights that may be infringed by your derivative 
 * works or by other works in which the Apple Software may be incorporated.
 * 
 * The Apple Software is provided by Apple on an "AS IS" basis.  APPLE MAKES NO WARRANTIES, 
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-
 * INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE 
 * SOFTWARE OR ITS USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 *
 * IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, 
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE, HOWEVER CAUSED AND 
 * WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR 
 * OTHERWISE, EVEN IF APPLE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


//
//	Includes
//

#import <Cocoa/Cocoa.h>
#import <DiskArbitration/DiskArbitration.h>
#import <IOKit/scsi/SCSITaskLib.h>
#import "AuthoringDeviceTester.h"


typedef struct Context
{
	id		document;
	int		result;
} Context;

//
// NB: This code example requires Tiger or later in order to work.
//

@interface MyDocument : NSDocument
{
	
	IBOutlet NSTextView *		testOutputTextView;
	IBOutlet NSButton *			testButton;
	IBOutlet NSPopUpButton *	testPopUpButton;
	IBOutlet NSButton *			exclusiveAccessButton;
	IBOutlet NSButton *			isExclusiveAccessAvailableButton;
	IBOutlet NSWindow *			theWindow;
	id							theAuthoringDeviceTester;
	id							theAuthoringDevice;
	
}

+ ( MyDocument * ) myDocument;

- ( NSWindow * ) theWindow;

- ( id ) theAuthoringDeviceTester;
- ( void ) setTheAuthoringDeviceTester: ( id ) value;

- ( id ) theAuthoringDevice;
- ( void ) setTheAuthoringDevice: ( id ) value;

- ( void ) runExclusiveTestSuite: ( SCSITaskDeviceInterface ** ) interface;
- ( int ) unmountMedia;
- ( int ) unmountAllPartitions: ( CFStringRef ) bsdName;

- ( IBAction ) switchTest: ( id ) sender;
- ( IBAction ) getExclusiveAccess: ( id ) sender;
- ( IBAction ) isExclusiveAccessAvailable: ( id ) sender;
- ( void ) diskUnmountCallback: ( DADiskRef ) disk
					 dissenter: ( DADissenterRef ) dissenter
					   context: ( Context * ) context;


//
//				Helper Methods
//

- ( void ) appendLogText: ( NSString * ) logString;
- ( IBAction ) clearLog: ( id ) sender;


@end
